Introduction
============
C++ Implementation of the test suite for the Special Session on Large
Scale Global Optimization at 2013 IEEE Congress on Evolutionary
Computation.

Note
----
If you are to use any part of this code, please cite the following publications:
X. Li, K. Tang, M. Omidvar, Z. Yang and K. Qin, "Benchmark Functions for the CEC'2013 Special Session and Competition on Large Scale Global Optimization," Technical Report, Evolutionary Computation and Machine Learning Group, RMIT University, Australia, 2013. 
http://goanna.cs.rmit.edu.au/~xiaodong/cec13-lsgo/competition/

Requirements
------------
- GNU Make
- GNU G++

Testing Environment
-------------------
- Debian GNU/Linux jessie/sid
- GNU Make 3.81
- g++ (Debian 4.7.3-4) 4.7.3

To compile 
-----------
type in 'make' in the root directory of source code

To run
------
./demo.out

To clean up
-----------
make clean

Contact
-------
Wenxiang Chen @ Computer Science Department, Colorado State University
Please feel free to contact me at <chenwx@cs.colostate.edu> for any enquiries or suggestions.

Last Updated: <2013-05-28 Tue 06:28>

